/* classes.js
	Example script to use classes for BrainVoyager QX 2.1 and higher.
	HB, BI, 020610.
*/

// ~~~~~~~~~~~~~~~~~~~~~~~~~ declarations ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

var filetype = "DICOM";
var firstfilename = "BetSor_050730_FACIM_AurRou-0002-0001-0001.dcm"; 
var nrofvols = 268;
var nrofvolsskip = 4;
var createamr = true;
var nrslices = 24;
var stcprefix = "untitled";
var swapbytes = false;
var mosaicx = 320;
var mosaicy = 320;
var nrbytes = 2;
var savingdir = "/Users/hester/Data/testdata/bettina/AurRou_METFAC_raw_data/functional/FFA_localizer_1/";
var volsinimg = 1;
var imgresx = 64;
var imgresy = 64;

// ~~~~~~~~~~~~~~~~~~~~~~~~~ the program ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

BrainVoyagerQX.PrintToLog("Start creating project...");
var factory = new ProjectFactory(filetype, savingdir+firstfilename, nrofvols, nrofvolsskip, createamr, nrslices, 
			stcprefix, swapbytes, mosaicx, mosaicy, nrbytes, savingdir, volsinimg, imgresx, imgresy);
BrainVoyagerQX.PrintToLog(factory.toString()); // print the project parameters
var fmr = factory.createproject();
fmr.SaveAs("run1.fmr");
BrainVoyagerQX.PrintToLog("Finished.");


// ~~~~~~~~~~~~~~~~~~~~~~~~~ class definition ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

function ProjectFactory(filetype, firstfilename, nrofvols, nrofvolsskip, createamr, nrslices, 
		stcprefix, swapbytes, mosaicx, mosaicy, nrbytes, savingdir, volsinimg, imgresx, imgresy) { 
	
	// properties of ProjectFactory class
	this.filetype = filetype; 
	this.firstfilename = firstfilename;
	this.nrofvols = nrofvols; 
	this.nrofvolsskip = nrofvolsskip; 
	this.createamr = createamr; 
	this.nrslices = nrslices; 
	this.stcprefix = stcprefix; 
	this.swapbytes = swapbytes; 	
	this.mosaicx = mosaicx; 
	this.mosaicy = mosaicy; 
	this.nrbytes = nrbytes; 
	this.savingdir = savingdir;
	this.volsinimg = volsinimg; 
	this.imgresx = imgresx; 
	this.imgresy = imgresy; 
	
	// function of ProjectFactory class
	this.createproject = function() {
		var project = BrainVoyagerQX.CreateProjectMosaicFMR(this.filetype, this.firstfilename, this.nrofvols, this.nrofvolsskip, this.createamr, this.nrslices, 
					this.stcprefix, this.swapbytes, this.mosaicx, this.mosaicy, this.nrbytes, this.savingdir, this.volsinimg, this.imgresx, this.imgresy);
		return project;
	}

	// function of ProjectFactory class
	this.toString = function() { 

		var projparams = "Project parameters:\n";
		projparams += "\tFiletype: " + this.filetype + "\n";
		projparams += "\tFirst file name: " + this.firstfilename + "\n";
		projparams += "\tNumber of volumes: " + this.nrofvols + "\n";
		projparams += "\tNumber of skipped volumes: " + this.nrofvolsskip + "\n";
		projparams += "\tCreate pseudo AMR: " + this.createamr + "\n";
		projparams += "\tNumber of slices: " + this.nrslices + "\n";
		projparams += "\tSTC prefix: " + this.stcprefix + "\n";
		projparams += "\tSwap bytes: " + this.swapbytes + "\n";
		projparams += "\tSize of mosaic image (x-axis): " + this.mosaicx + "\n";
		projparams += "\tSize of mosaic image (y-axis): " + this.mosaicy + "\n";
		projparams += "\tNumber of bytes: " + this.nrbytes + "\n";
		projparams += "\tSaving directory: " + this.savingdir + "\n";
		projparams += "\tNumber of volumes in mosaic file: " + this.volsinimg + "\n";
		projparams += "\tSize of individual image (x-axis): " + this.imgresx + "\n";
		projparams += "\tSize of individual image (y-axis): " + this.imgresy + "\n";
		return projparams; 

	}
}